@@ -10,17 +10,9 @@ from netbox_storage.models import Filesystem
 
 class NestedFilesystemSerializer(WritableNestedSerializer):
     url = serializers.HyperlinkedIdentityField(
-        view_name="plugins-api:netbox_dns-api:view-detail"
+        view_name="plugins-api:netbox_storage-api:filesystem-detail"
     )
 
     class Meta:
         model = Filesystem
-        fields = ['id', 'filesystem']
-
-    url = serializers.HyperlinkedIdentityField(
-        view_name="plugins-api:netbox_dns-api:view-detail"
-    )
-
-    class Meta:
-        model = View
-        fields = ["id", "url", "display", "name"]
\ No newline at end of file
+        fields = ["id", "url", "display", "filesystem"]
