@@ -47,7 +47,7 @@ class Drive(NetBoxModel):
     def save(self, *args, **kwargs):
         number_of_hard_drives = Drive.objects.filter(virtual_machine=self.virtual_machine).order_by("created").count()
 
-        self.identifier = f"Festplatte {number_of_hard_drives + 1}"
+        self.identifier = f"Hard Drive {number_of_hard_drives + 1}"
         super(Drive, self).save(*args, **kwargs)
 
 
@@ -75,19 +75,11 @@ class Filesystem(NetBoxModel):
         return reverse("plugins:netbox_storage:filesystem", kwargs={"pk": self.pk})
 
     def __str__(self):
-        return f"Filesystem: {self.filesystem}"
+        return f"{self.filesystem}"
 
     class Meta:
         ordering = ("filesystem", "description")
 
-# Produziert einen Fehler, weitere Untersuchungen notwendig
-# @register_search
-# class FilesystemIndex(SearchIndex):
-#    model = Filesystem
-#    fields = (
-#        ("filesystem", 100)
-#    )
-
 
 class LinuxVolume(NetBoxModel):
     vg_name = models.CharField(
@@ -99,7 +91,7 @@ class LinuxVolume(NetBoxModel):
     path = models.CharField(
         max_length=255,
     )
-    fs = models.OneToOneField(
+    fs = models.ForeignKey(
         Filesystem,
         on_delete=models.CASCADE,
         related_name="fs_linux",
@@ -143,7 +135,7 @@ class WindowsVolume(NetBoxModel):
     drive_name = models.CharField(
         max_length=255,
     )
-    fs = models.OneToOneField(
+    fs = models.ForeignKey(
         Filesystem,
         on_delete=models.CASCADE,
         related_name="fs_windows",
@@ -161,19 +153,10 @@ class WindowsVolume(NetBoxModel):
         ]
 
     def get_absolute_url(self):
-        return reverse("plugins:netbox_storage:linuxvolume", kwargs={"pk": self.pk})
+        return reverse("plugins:netbox_storage:windowsvolume", kwargs={"pk": self.pk})
 
     def __str__(self):
         return f"Name: {self.drive_name} filesystem: {self.fs}"
 
     class Meta:
         ordering = ("drive_name", "fs")
-
-
-@register_search
-class WindowsVolumeIndex(SearchIndex):
-    model = LinuxVolume
-    fields = (
-        ("drive_name", 100),
-        ("fs", 100),
-    )
